package com.lib.rncastlabs;

import android.content.Context;
import android.net.Uri;
import android.text.TextUtils;
import com.castlabs.android.SdkConsts;
import com.castlabs.android.drm.Drm;
import com.castlabs.android.drm.DrmTodayConfiguration;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.BaseViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.ViewGroupManager;
import com.facebook.react.uimanager.annotations.ReactProp;
import java.util.Map;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import static com.lib.rncastlabs.Utils.REACT_CLASS_NAME;

public class ReactCastLabsViewManager extends ViewGroupManager<ReactCastLabsPlayerView> {

  private static final String PROP_SRC = "src";
  private static final String PROP_SRC_URI = "uri";
  private static final String PROP_SRC_TYPE = "type";

  @Nonnull @Override public String getName() {
    return  REACT_CLASS_NAME;
  }

  @Nonnull @Override
  protected ReactCastLabsPlayerView createViewInstance(@Nonnull ThemedReactContext reactContext) {
    return new ReactCastLabsPlayerView(reactContext);
  }

  @Override
  public void onDropViewInstance(ReactCastLabsPlayerView view) {
    view.cleanupResources();
  }

  @ReactProp(name = PROP_SRC)
  public void setSrc(final ReactCastLabsPlayerView videoView, @Nullable ReadableMap src) {
    Context context = videoView.getContext().getApplicationContext();
    String uriString = src.hasKey(PROP_SRC_URI) ? src.getString(PROP_SRC_URI) : null;
    String extension = src.hasKey(PROP_SRC_TYPE) ? src.getString(PROP_SRC_TYPE) : null;


    if (TextUtils.isEmpty(uriString)) {
      return;
    }

    if (startsWithValidScheme(uriString)) {

      videoView.setSrc(new Utils.BundleBuilder()
          .put(SdkConsts.INTENT_URL, uriString)
          .put(SdkConsts.INTENT_DRM_CONFIGURATION, new DrmTodayConfiguration.Builder(
              DrmTodayConfiguration.DRMTODAY_STAGING,
              "purchase",
              "sessionId",
              "dzones",
              "17881797-896f-4272-bfcb-9e9c820c9049",
              Drm.Widevine
          ).get())
          .get());
    } else {
      int identifier = context.getResources().getIdentifier(
          uriString,
          "drawable",
          context.getPackageName()
      );
      if (identifier == 0) {
        identifier = context.getResources().getIdentifier(
            uriString,
            "raw",
            context.getPackageName()
        );
      }
      if (identifier > 0) {

      }
    }
  }

  private boolean startsWithValidScheme(String uriString) {
    return uriString.startsWith("http://")
        || uriString.startsWith("https://")
        || uriString.startsWith("content://")
        || uriString.startsWith("file://")
        || uriString.startsWith("asset://");
  }
}
